@@ -21,7 +21,6 @@ use function is_resource;
 use function is_string;
 use function mb_internal_encoding;
 use function mb_language;
-use function method_exists;
 use function preg_replace;
 use function range;
 use function str_repeat;
@@ -29,7 +28,6 @@ use Error;
 use Exception;
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\DataProvider;
-use PHPUnit\Framework\Attributes\RequiresPhp;
 use PHPUnit\Framework\Attributes\RequiresPhpExtension;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
@@ -231,7 +229,7 @@ EOF,
                 0,
             ],
             [
-                implode('', array_map('chr', range(0x0E, 0x1F))),
+                implode('', array_map(chr(...), range(0x0E, 0x1F))),
                 'Binary String: 0x0e0f101112131415161718191a1b1c1d1e1f',
                 0,
             ],
@@ -351,9 +349,9 @@ EOF,
     public static function provideNonBinaryMultibyteStrings(): array
     {
         return [
-            [implode('', array_map('chr', range(0x09, 0x0D))), 9],
-            [implode('', array_map('chr', range(0x20, 0x7F))), 96],
-            [implode('', array_map('chr', range(0x80, 0xFF))), 128],
+            [implode('', array_map(chr(...), range(0x09, 0x0D))), 9],
+            [implode('', array_map(chr(...), range(0x20, 0x7F))), 96],
+            [implode('', array_map(chr(...), range(0x80, 0xFF))), 128],
         ];
     }
 
@@ -485,7 +483,7 @@ EOF;
     {
         $this->assertSame(
             $expected,
-            $this->trimNewline((new Exporter(0, $maxLengthForStrings))->shortenedExport($value)),
+            $this->trimNewline(new Exporter(0, $maxLengthForStrings)->shortenedExport($value)),
         );
 
         $this->assertSame(
@@ -551,7 +549,7 @@ EOF;
     #[DataProvider('shortenedRecursiveExportProvider')]
     public function testShortenedRecursiveExport(array $value, string $expected, int $limit): void
     {
-        $this->assertEquals($expected, (new Exporter($limit))->shortenedRecursiveExport($value));
+        $this->assertEquals($expected, new Exporter($limit)->shortenedRecursiveExport($value));
     }
 
     public function testShortenedRecursiveOccurredRecursion(): void
@@ -567,14 +565,10 @@ EOF;
         $this->assertEquals('*RECURSION*', (new Exporter)->shortenedRecursiveExport($value, processed: $context));
     }
 
-    #[RequiresPhp('^8.4')]
     public function testShortenedExportDoesNotInitializeLazyObject(): void
     {
         $reflector = new ReflectionClass(ExampleClass::class);
 
-        assert(method_exists($reflector, 'newLazyProxy'));
-        assert(method_exists($reflector, 'isUninitializedLazyObject'));
-
         $object = $reflector->newLazyProxy(static fn () => new ExampleClass('bar'));
 
         (new Exporter)->shortenedExport($object, 10);
